NengoDL
=======

.. toctree::
    :maxdepth: 3

    Introduction <introduction>
    installation
    user-guide
    reference
    examples
    resources
    project

`Github <https://github.com/nengo/nengo-dl>`_ |
`PyPI <https://pypi.org/project/nengo-dl>`_
